<?php

namespace Bydedi\Tracking\Nosto;

/**
 * Class Nosto
 * @package Bydedi\Tracking\Nosto
 */
class Nosto
{
    /**
     * @var bool
     */
    protected static $isInit = false;
    /**
     * @var array|null $config
     */
    protected static $config = null;

    /**
     * @param array $config
     */
    public static function init($config = array())
    {
        if (!isset($config['vat'])) {
            $config['vat'] = true;
        }
        self::$config = $config;
    }

    /**
     * Check if it's initialized.
     * If not trigger a warning error
     */
    protected static function triggerErrorIfNotInit()
    {
        if (is_null(self::$config)) {
            trigger_error("Nosto n'est pas initialisé", E_USER_WARNING);
        }
    }

    /**
     * @param $param
     * @return string
     */
    public static function common($param)
    {
        self::triggerErrorIfNotInit();

        if (self::$isInit == true) {
            return "";
        }

        self::$isInit = true;

        $tracker = '
        <script type="text/javascript">
        //<![CDATA[
        (function(){function a(a){var b,c,d=window.document.createElement("iframe");
        d.src="javascript:false",(d.frameElement||d).style.cssText="width: 0; height: 0; border: 0";
        var e=window.document.createElement("div");e.style.display="none";
        var f=window.document.createElement("div");e.appendChild(f),window.document.body.insertBefore(e,window.document.body.firstChild),
        f.appendChild(d);
        try{c=d.contentWindow.document}catch(g){b=document.domain,d.src="javascript:var d=document.open();d.domain=\'"+b+"\';void(0);",
        c=d.contentWindow.document}
        return c.open()._l=function(){b&&(this.domain=b);
        var c=this.createElement("scr".concat("ipt"));c.src=a,this.body.appendChild(c)},
        c.write("<bo".concat(\'dy onload="document._l();">\')),c.close(),d}
        var b="nostojs";window[b]=window[b]||function(a){(window[b].q=window[b].q||[]).push(a)},
        window[b].l=new Date;var c=function(d,e){if(!document.body)return setTimeout(function(){c(d,e)},30);e=e||{},
        window[b].o=e;var f=document.location.protocol,
        g=["https:"===f?f:"http:","//",e.host||"connect.nosto.com",e.path||"/include/",d].join("");a(g)};
        window[b].init=c})();
        
        nostojs.init(\''.self::$config['id'].'\');
        
        //]]>
        </script>
        ';

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_main'], $tracker);
        }
    }

    /**
     * @param array $param
     */
    public static function getVisites($param = array())
    {
        self::common($param);
        self::customer($param);
    }

    /**
     * @param array $param
     */
    public static function customer($param=array())
    {
        self::common($param);

        if (!empty($param['extra']['client_id'])) {
            $client = new \Client();
            list($arrClient) = $client->get(array('client_id' => $param['extra']['client_id']));
            $out='
                <div class="nosto_customer" style="display:none">
                <span class="email">'.$arrClient['client_email'].'</span>
                <span class="first_name">'.$arrClient['client_prenom'].'</span>
                <span class="last_name">'.$arrClient['client_nom'].'</span>
                
                <!-- Optional properties -->
                       
                <span class="birth_date">'.$arrClient['client_ddn'].'</span>
                </div>
            ';

            if (isset($param['smarty'])) {
                $param['smarty']->reassign(self::$config['position_tags'], $out);
            }
        }
    }

    /**
     * @param array $param
     */
    public static function index($param = array())
    {
        self::common($param);

        $out=' <div class="nosto_page_type" style="display:none">front</div>';

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_tags'], $out);
        }
    }

    /**
     * @param array $param
     */
    public static function produit($param = array())
    {
        self::common($param);

        $prix=round(self::$config['vat'] ? $param['produit_prix_ttc'] : $param['produit_prix_ht'], 2);
        $listPrice=round(self::$config['vat'] ? $param['prix_ttc'] : $param['prix_ht'], 2);

        if ($listPrice < $prix) {
            $listPrice = $prix;
        }

        $parameters = array(
            'url' => $param['url'],
            'product_id' => $param['produit_id'],
            'name' => $param['produit_nom_nom'],
            'image_url' => $param['produit_image_detail'],
            'price' => $prix,
            'price_currency_code' => !empty($param['currency']) ? $param['currency'] : 'EUR',
            'availability' => ($param['produit_quantite'] > 0 || $param['prod_appro'] == 1) ? 'InStock': 'OutOfStock',
            'description' => $param['produit_nom_desc'],
            'list_price' => $listPrice,
            'brand' => $param['marque_nom'],
            'tag1' => !empty($param['tag1']) ? $param['tag1'] : '',
            'tag2' => !empty($param['tag2']) ? $param['tag2'] : '',
            'tag3' => !empty($param['tag3']) ? $param['tag3'] : '',
        );

        if (!empty($param['reviews'])) {
            $parameters['review_count'] = $param['reviews']['nbcom'];
            $parameters['rating_value'] = $param['reviews']['moyenne_note'];
        }

        if (!empty($param['breadcrumb'])) {
            $parameters['category'] = '';
            if (count($param['breadcrumb']) > 4) {
                $param['breadcrumb'] = array_slice($param['breadcrumb'],0,4);
            }
            foreach ($param['breadcrumb'] as $a) {
                $parameters['category'] .= '/' . $a['nom'];
            }
        }

        if (!empty($param['produit_date_ajout']) && $param['produit_date_ajout'] != '0000-00-00 00:00:00') {
            $parameters['date_published'] = $param['produit_date_ajout'];
        }

        $out = '<div class="nosto_product" style="display:none">'."\n";

        foreach ($parameters as $key => $value) {
            if (is_array($value)) {
                foreach ($value as $v) {
                    $out.='<span class="'.$key.'">'.$v.'</span>'."\n";
                }
            } else {
                $out.='<span class="'.$key.'">'.$value.'</span>'."\n";
            }
        }
        $out.='</div>'."\n";
        $out.='<div class="nosto_page_type" style="display:none">product</div>';

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_tags'], $out);
        }
    }

    /**
     * @param array $param
     */
    public static function recapitulatif($param=array())
    {
        self::common($param);

        $out=' <div class="nosto_page_type" style="display:none">order</div>';
        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_tags'], $out);
        }
    }

    /**
     * @param array $param
     */
    public static function recherche($param=array())
    {
        self::common($param);

        $out=' <div class="nosto_page_type" style="display:none">search</div>'."\n";
        $out.=' <div class="nosto_search_term" style="display:none">'.$param['keyword'].'</div>';
        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_tags'], $out);
        }
    }

    /**
     * @param array $param
     */
    public static function cms($param=array())
    {
        self::common($param);

        $out=' <div class="nosto_page_type" style="display:none">front</div>';
        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_tags'], $out);
        }
    }

    /**
     * @param array $param
     * @return bool
     */
    public static function paiement($param = array())
    {
        self::common($param);

        if (empty($param['commande_id'])) {
            return false;
        }

        // recuperation des données
        $commande = new \Commande;
        list($arrCommande) = $commande->get(array('commande_id' => $param['commande_id']));
        $arrCommande['products'] = $commande->getProduit(array('commande_id' => $param['commande_id']));

        if (!empty($arrCommande['client_id'])) {
            $client = new \Client();
            $arrClient = $client->get(array('client_id' => $arrCommande['client_id']));

            if (!empty($arrClient)) {
                $arrCommande['client_prenom'] = $arrClient[0]['client_prenom'];
                $arrCommande['client_nom'] = $arrClient[0]['client_nom'];
            }
        }

        $produit="";
        foreach ($arrCommande['products'] as $p) {
            $produit.='<div class="line_item">';
            $produit.='<span class="product_id">'.$p['produit_id'].'</span>';
            $produit.='<span class="quantity">'.$p['qte'].'</span>';
            $produit.='<span class="name">'.$p['produit_nom_nom'].'</span>';
            $produit.='<span class="unit_price">'.(self::$config['vat'] ? $p['prix_ttc'] : $p['prix_ht']).'</span>';
            $produit.='<span class="price_currency_code">EUR</span>';
            $produit.='</div>';
        }

        $out = '
        <div class="nosto_purchase_order" style="display:none">
            <span class="order_number">'.$param['commande_id'].'</span>
            <div class="buyer">
                <span class="email">'. $arrCommande['client_email'].'</span>
                <span class="first_name">'.$arrCommande['client_prenom'].'</span>
                <span class="last_name">'.$arrCommande['client_nom'].'</span>
            </div>
            <div class="purchased_items">
            <!-- Check your ecom engine how to loop over purchased items to produce the line_item divs  -->
                '.$produit.'
            </div>
        </div>
                ';

        $out .= '<div class="nosto_page_type" style="display:none">order</div>';


        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_tags'], $out);
        }
    }

    /**
     * @param array $param
     */
    public static function listing($param = array())
    {
        self::common($param);

        $ariane = $param['breadcrumb'];

        $out = '';

        if (!empty($ariane)) {
            $categorie = '';
            foreach ($ariane as $c) {
                $categorie .='/'. $c['nom'];
            }

            $out .= '<div class="nosto_category" style="display:none">' . rtrim($categorie, '/') . '</div>
            <div class="nosto_page_type" style="display:none">category</div>';
        }

        if (!empty($param['nosto_tag'])) {
            if (is_array($param['nosto_tag'])) {
                foreach ($param['nosto_tag'] as $v) {
                    $out.='<span class="nosto_tag">'.$v.'</span>'."\n";
                }
            } else {
                $out.='<span class="nosto_tag">'.$param['nosto_tag'].'</span>'."\n";
            }
        }

        if (!empty($out) && isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_tags'], $out);
        }
    }

    /**
     * @param array $param
     */
    public static function panier($param = array())
    {
        self::common($param);

        $produit="";
        foreach ($param['extra']['produits'] as $p) {
            if (!empty($p['produit_id'])) {
                $produit.='<div class="line_item">';
                $produit.='<span class="product_id">'.$p['produit_id'].'</span>';
                $produit.='<span class="quantity">'.$p['qte'].'</span>';
                $produit.='<span class="name">'.$p['produit_nom'].'</span>';
                $produit.='<span class="unit_price">'.(self::$config['vat'] ? $p['prix_ttc'] : $p['prix_ht']).'</span>';
                $produit.='<span class="price_currency_code">EUR</span>';
                $produit.='</div>';
            }
        }

        $out='
        <!-- Tag your customer\'s shopping cart contents, replace static example values to equivalent database/ecom engine variables  -->
        <div class="nosto_cart" style="display:none">
        <!-- Check your ecom engine how to loop over items in customer\'s shopping cart to produce the line_item divs  -->               
         '.$produit.'                          
        </div>
        <div class="nosto_page_type" style="display:none">cart</div>
       ';

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_tags'], $out);
        }
    }

    /**
     * @param array $param
     */
    public static function not_found($param = array())
    {
        self::common($param);

        $out='<div class="nosto_page_type" style="display:none">notfound</div>';

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_tags'], $out);
        }
    }

    /**
     * @param array $param
     */
    public static function confirmation($param = array())
    {
        self::common($param);

        $out='<div class="nosto_page_type" style="display:none">order</div>';

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_tags'], $out);
        }
    }
}
